4.25. umbra.exceptions — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »

# 4.25. umbra.exceptions

exceptions.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines Umbra package exceptions.

Others:

## 4.25.1. Functions

`umbra.exceptions.` `notifyExceptionHandler`(*args)

  This definition provides a notifier exception handler.

  Parameters: | *args – Arguments. ( * )
  Returns: | Definition success. ( Boolean )

## 4.25.2. Classes

class `umbra.exceptions.` `AbstractEngineError`(value)

  Bases: `foundations.exceptions.AbstractError`

  This class is the abstract base class for engine related exceptions.

  This method initializes the class.

  Parameters: | value – Error value or message. ( String )

class `umbra.exceptions.` `EngineConfigurationError`(value)

  Bases: `umbra.exceptions.AbstractEngineError`

  This class is used for engine configuration exceptions.

  This method initializes the class.

  Parameters: | value – Error value or message. ( String )

class `umbra.exceptions.` `EngineInitializationError`(value)

  Bases: `umbra.exceptions.AbstractEngineError`

  This class is used for engine initialization exceptions.

  This method initializes the class.

  Parameters: | value – Error value or message. ( String )

class `umbra.exceptions.` `ResourceExistsError`(value)

  Bases: `foundations.exceptions.AbstractOsError`

  This class is used for non existing resource exceptions.

  This method initializes the class.

  Parameters: | value – Error value or message. ( String )

class `umbra.exceptions.` `AbstractActionsManagerError`(value)

  Bases: `foundations.exceptions.AbstractError`

  This class is the abstract base class for `umbra.managers.actionsManager.ActionsManager` related exceptions.

  This method initializes the class.

  Parameters: | value – Error value or message. ( String )

class `umbra.exceptions.` `CategoryExistsError`(value)

  Bases: `umbra.exceptions.AbstractActionsManagerError`

  This class is used for non existing category exceptions.

  This method initializes the class.

  Parameters: | value – Error value or message. ( String )

class `umbra.exceptions.` `ActionExistsError`(value)

  Bases: `umbra.exceptions.AbstractActionsManagerError`

  This class is used for non existing action exceptions.

  This method initializes the class.

  Parameters: | value – Error value or message. ( String )

class `umbra.exceptions.` `AbstractPatchesManagerError`(value)

  Bases: `foundations.exceptions.AbstractError`

  This class is the abstract base class for `umbra.managers.patchesManager.PatchesManager` related exceptions.

  This method initializes the class.

  Parameters: | value – Error value or message. ( String )

class `umbra.exceptions.` `PatchRegistrationError`(value)

  Bases: `umbra.exceptions.AbstractPatchesManagerError`

  This class is used for patch registration exceptions.

  This method initializes the class.

  Parameters: | value – Error value or message. ( String )

class `umbra.exceptions.` `PatchInterfaceError`(value)

  Bases: `umbra.exceptions.AbstractPatchesManagerError`

  This class is used for patch interface exceptions.

  This method initializes the class.

  Parameters: | value – Error value or message. ( String )

class `umbra.exceptions.` `PatchApplyError`(value)

  Bases: `umbra.exceptions.AbstractPatchesManagerError`

  This class is used for patch apply exceptions.

  This method initializes the class.

  Parameters: | value – Error value or message. ( String )

class `umbra.exceptions.` `AbstractLayoutsManagerError`(value)

  Bases: `foundations.exceptions.AbstractError`

  This class is the abstract base class for `umbra.managers.layoutsManager.LayoutsManager` related exceptions.

  This method initializes the class.

  Parameters: | value – Error value or message. ( String )

class `umbra.exceptions.` `LayoutRegistrationError`(value)

  Bases: `umbra.exceptions.AbstractLayoutsManagerError`

  This class is used for layout registration exceptions.

  This method initializes the class.

  Parameters: | value – Error value or message. ( String )

class `umbra.exceptions.` `LayoutExistError`(value)

  Bases: `umbra.exceptions.AbstractLayoutsManagerError`

  This class is used for non existing layout exceptions.

  This method initializes the class.

  Parameters: | value – Error value or message. ( String )

class `umbra.exceptions.` `AbstractFileSystemEventsManagerError`(value)

  Bases: `foundations.exceptions.AbstractError`

  This class is the abstract base class for `umbra.managers.fileSystemEventsManager.FileSystemEventsManager` related exceptions.

  This method initializes the class.

  Parameters: | value – Error value or message. ( String )

class `umbra.exceptions.` `PathRegistrationError`(value)

  Bases: `umbra.exceptions.AbstractFileSystemEventsManagerError`

  This class is used for path registration exceptions.

  This method initializes the class.

  Parameters: | value – Error value or message. ( String )

class `umbra.exceptions.` `PathExistsError`(value)

  Bases: `umbra.exceptions.AbstractFileSystemEventsManagerError`

  This class is used for non existing path exceptions.

  This method initializes the class.

  Parameters: | value – Error value or message. ( String )

class `umbra.exceptions.` `AbstractLanguageError`(value)

  Bases: `foundations.exceptions.AbstractError`

  This class is the abstract base class for language related exceptions.

  This method initializes the class.

  Parameters: | value – Error value or message. ( String )

class `umbra.exceptions.` `LanguageGrammarError`(value)

  Bases: `umbra.exceptions.AbstractLanguageError`

  This class is used for language grammar exceptions.

  This method initializes the class.

  Parameters: | value – Error value or message. ( String )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »